package net.minecraft.src.forestry.api;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;

public class APIBridge {

	/**
	 * Add new fuels for the bronze engine directly here
	 */
	public static HashMap<Integer, BronzeEngineFuel> bronzeEngineFuel = new HashMap<Integer, BronzeEngineFuel>();
	/**
	 * Add new fuels for the fermenter directly here
	 */
	public static HashMap<Integer, FermenterFuel> fermenterFuel = new HashMap<Integer, FermenterFuel>();
	/**
	 * Add new resources for the fermenter directly here
	 */
	public static HashMap<Integer, FermenterResource> fermenterResource = new HashMap<Integer, FermenterResource>();
	
	public static int humusBlockId;
	
	private static ArrayList<IBoilerHandler> boilerHandler = new ArrayList<IBoilerHandler>();
	private static HashMap<Integer, BoilerPackage> boilerPackagesByMeta = new HashMap<Integer, BoilerPackage>();  
	private static ArrayList<IHarvesterHandler> harvesterHandler = new ArrayList<IHarvesterHandler>();
	private static HashMap<Integer, HarvesterPackage> harvesterPackagesByMeta = new HashMap<Integer, HarvesterPackage>();  
	private static ArrayList<IPlanterHandler> planterHandler = new ArrayList<IPlanterHandler>();
	private static HashMap<Integer, PlanterPackage> planterPackagesByMeta = new HashMap<Integer, PlanterPackage>();
	
	public static void RegisterAllPackageNames()
	{
		for(IBoilerHandler handler : boilerHandler)
			handler.registerAllPackageNames();
		for(IHarvesterHandler handler : harvesterHandler)
			handler.registerAllPackageNames();
		for(IPlanterHandler handler : planterHandler)
			handler.registerAllPackageNames();
	}
	
	/**
	 * Use to register a new {@link}BoilerPackage with Forestry
	 * @param meta Metadata to use for the new machine. Valid values are 0-15 with 0-5 reserved for Forestry's own machines
	 * @param pack {@link}BoilerPackage containing the necessary information for the new machine.
	 * @return true if the package was successfully added, false otherwise.
	 */
	public static boolean RegisterBoilerPackage(int meta, BoilerPackage pack)
	{
		// Key already taken, skip adding this planter
		if(boilerPackagesByMeta.containsKey(meta))
			return false;
		
		boilerPackagesByMeta.put(meta, pack);
		for(IBoilerHandler handler : boilerHandler)
			handler.registerBoiler(meta, pack);
		return true;
	}
	
	/**
	 * Use to register a new {@link}HarvesterPackage with Forestry
	 * @param meta Metadata to use for the new machine. Valid values are 0-15 with 0-5 reserved for Forestry's own machines
	 * @param pack {@link}HarvesterPackage containing the necessary information for the new machine.
	 * @return true if the package was successfully added, false otherwise.
	 */
	public static boolean RegisterHarvesterPackage(int meta, HarvesterPackage pack)
	{
		// Key already taken, skip adding this planter
		if(harvesterPackagesByMeta.containsKey(meta))
			return false;
		
		harvesterPackagesByMeta.put(meta, pack);
		for(IHarvesterHandler handler : harvesterHandler)
			handler.registerHarvester(meta, pack);
		return true;
	}
	
	/**
	 * Use to register a new {@link}PlanterPackage with Forestry
	 * @param meta Metadata to use for the new machine. Valid values are 0-15 with 0-5 reserved for Forestry's own machines
	 * @param pack {@link}PlanterPackage containing the necessary information for the new machine.
	 * @return true if the package was successfully added, false otherwise.
	 */
	public static boolean RegisterPlanterPackage(int meta, PlanterPackage pack)
	{
		// Key already taken, skip adding this planter
		if(planterPackagesByMeta.containsKey(meta))
			return false;

		// Register blueprints
		StructureBlueprint.index.put(pack.area.id, pack.area);
		StructureBlueprint.index.put(pack.soil.id, pack.soil);
		StructureBlueprint.index.put(pack.plantation.id, pack.plantation);
		
		planterPackagesByMeta.put(meta, pack);
		for(IPlanterHandler handler : planterHandler)
			handler.registerPlanter(meta, pack);
		return true;
	}
	
	// EVERYTHING BELOW IS FOR INTERNAL USE ONLY
	
	public static void RegisterBoilerHandler(IBoilerHandler handler)
	{
		boilerHandler.add(handler);
	}
	
	public static Iterator<Integer> GetBoilerKeyIterator()
	{
		return boilerPackagesByMeta.keySet().iterator();
	}
	
	public static BoilerPackage GetBoilerPackage(int meta)
	{
		return boilerPackagesByMeta.get(meta);
	}
	
	public static boolean HasBoilerPackage(int meta)
	{
		return boilerPackagesByMeta.containsKey(meta);
	}
	
	public static void RegisterHarvesterHandler(IHarvesterHandler handler)
	{
		harvesterHandler.add(handler);
	}
	
	public static Iterator<Integer> GetHarvesterKeyIterator()
	{
		return harvesterPackagesByMeta.keySet().iterator();
	}
	
	public static HarvesterPackage GetHarvesterPackage(int meta)
	{
		return harvesterPackagesByMeta.get(meta);
	}
	
	public static boolean HasHarvesterPackage(int meta)
	{
		return harvesterPackagesByMeta.containsKey(meta);
	}
	
	public static void RegisterPlanterHandler(IPlanterHandler handler)
	{
		planterHandler.add(handler);
	}
	
	public static Iterator<Integer> GetPlanterKeyIterator()
	{
		return planterPackagesByMeta.keySet().iterator();
	}
	
	public static PlanterPackage GetPlanterPackage(int meta)
	{
		return planterPackagesByMeta.get(meta);
	}
	
	public static boolean HasPlanterPackage(int meta)
	{
		return planterPackagesByMeta.containsKey(meta);
	}
	
}
