package net.minecraft.src.forestry.api;

import java.util.HashMap;

import net.minecraft.src.Block;
import net.minecraft.src.ItemStack;
import net.minecraft.src.ModLoader;

public class StructureBlueprint
{
	public String id;
	// Y / X / Z
	private int[][][] pattern;
	
	public StructureBlueprint(String id, Vect area)
	{
		this.id = id;
		this.pattern = new int[area.y][area.x][area.z];
	}
	
	public void setPlane(int y, int[][] plane)
	{
		pattern[y] = plane;
	}
	
	public int getBlockId(Vect pos)
	{
		return this.pattern[pos.y][pos.x][pos.z];
	}
	
	public int getYLength()
	{
		return pattern.length;
	}
	
	public int getXLength()
	{
		return pattern[0].length;
	}
	
	public int getZLength()
	{
		return pattern[0][0].length;
	}
	
	//public static final StructureBlueprint[] index = new StructureBlueprint[255];	
	//public static final StructureBlueprint defaultArboretum = new StructureBlueprint(0, new Vect(15, 10, 15));
	public static final HashMap<String, StructureBlueprint> index = new HashMap<String, StructureBlueprint>();
	
	public static StructureBlueprint getBlueprint(String id) {
		if(index.containsKey(id))
			return index.get(id);
		else {
			ModLoader.getLogger().severe("Tried to retrieve unknown StructureBlueprint identified by " + id);
			return null;
		}
	}
	
	public static final StructureBlueprint defaultArboretum = new StructureBlueprint("defaultArboretum", new Vect(15, 10, 15));
	
	static
	{
		int i = 0;
		int j = 0;
		int k = 0;
		int l = 0;
		int m = 0;
		
		i = Block.brick.blockID;
		j = Block.planks.blockID;
		k = Block.glass.blockID;
		int[][] arboretum0 = new int[][] {
				new int[] {i,i,i,i,i,i,i,i,i,i,i,i,i,i,i}, // 1
				new int[] {i,0,0,0,0,0,0,0,0,0,0,0,0,0,i}, // 2
				new int[] {i,0,0,0,0,0,0,0,0,0,0,0,0,0,i}, // 3
				new int[] {i,0,0,0,0,0,0,0,0,0,0,0,0,0,i}, // 4
				new int[] {i,0,0,0,j,j,j,j,j,j,j,0,0,0,i}, // 5
				new int[] {i,0,0,0,j,j,j,j,j,j,j,0,0,0,i}, // 6
				new int[] {i,0,0,0,j,j,j,j,j,j,j,0,0,0,i}, // 7
				new int[] {i,0,0,0,j,j,j,0,j,j,j,0,0,0,i}, // 8
				new int[] {i,0,0,0,j,j,j,j,j,j,j,0,0,0,i}, // 9
				new int[] {i,0,0,0,j,j,j,j,j,j,j,0,0,0,i}, // 10
				new int[] {i,0,0,0,j,j,j,j,j,j,j,0,0,0,i}, // 11
				new int[] {i,0,0,0,0,0,0,0,0,0,0,0,0,0,i}, // 12
				new int[] {i,0,0,0,0,0,0,0,0,0,0,0,0,0,i}, // 13
				new int[] {i,0,0,0,0,0,0,0,0,0,0,0,0,0,i}, // 14
				new int[] {i,i,i,i,i,i,i,i,i,i,i,i,i,i,i}  // 15
			};
		defaultArboretum.setPlane(0, arboretum0);
		int[][] arboretum1 = new int[][] {
				new int[] {i,0,0,0,0,0,0,0,0,0,0,0,0,0,i}, // 1
				new int[] {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}, // 2
				new int[] {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}, // 3
				new int[] {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}, // 4
				new int[] {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}, // 5
				new int[] {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}, // 6
				new int[] {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}, // 7
				new int[] {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}, // 8
				new int[] {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}, // 9
				new int[] {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}, // 10
				new int[] {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}, // 11
				new int[] {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}, // 12
				new int[] {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}, // 13
				new int[] {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}, // 14
				new int[] {i,0,0,0,0,0,0,0,0,0,0,0,0,0,i}  // 15
			};
		defaultArboretum.setPlane(1, arboretum1);
		defaultArboretum.setPlane(2, arboretum1);
		defaultArboretum.setPlane(3, arboretum1);
		defaultArboretum.setPlane(4, arboretum1);
		defaultArboretum.setPlane(5, arboretum1);
		defaultArboretum.setPlane(6, arboretum1);
		defaultArboretum.setPlane(7, arboretum1);
		defaultArboretum.setPlane(8, arboretum1);
		defaultArboretum.setPlane(9, arboretum1);

	}
	
}
